geometric_mean_score
====================================================================

.. currentmodule:: imbalanced_ensemble.metrics

.. autofunction:: geometric_mean_score

.. include:: ../../../back_references/imbalanced_ensemble.metrics.geometric_mean_score.examples

.. raw:: html

    <div style='clear:both'></div>